%global extraver 11

Name:           ocaml-mccs
Version:        1.1
Release:        %mkrel 7
Summary:        Multi Criteria CUDF Solver with OCaml bindings
# Original C/C++ code is BSD, OCaml bindings are LGPL.
# Linking exception, see included COPYING file.
License:        BSD and LGPLv3+ with exceptions
Group:          Development/OCaml
URL:            https://github.com/AltGr/ocaml-mccs
# Upstream's use of a '+' instead of a '.' makes this hard to use a macro.
Source0:        https://github.com/AltGr/ocaml-mccs/archive/%{version}+%{extraver}/%{version}+%{extraver}.tar.gz

BuildRequires:  ocaml
BuildRequires:  ocaml-dune
BuildRequires:  gcc
BuildRequires:  gcc-c++
BuildRequires:  ocaml-findlib-devel
BuildRequires:  ocaml-cudf-devel
BuildRequires:  glpk-devel

%description
mccs (which stands for Multi Criteria CUDF Solver) is a CUDF problem
solver developed at UNS during the European MANCOOSI project.

This project contains a stripped-down version of the mccs solver,
taken from snapshot 1.1, with a binding as an OCaml library, and
building with jbuilder.

The binding enables interoperation with binary CUDF data from the
OCaml CUDF library, and removes the native C++ parsers and printers.

%package        devel
Summary:        Development files for %{name}
Group:          Development/OCaml
Requires:       %{name} = %{version}-%{release}

%description    devel
The %{name}-devel package contains libraries and signature files for
developing applications that use %{name}.

%prep
%autosetup -n %{name}-%{version}-%{extraver}

%build
dune build -p mccs %{?_smp_mflags}

%install
# This is an opam dependency. Tragically it means we must manually install,
# since the jbuilder install command only works with opam-installer.
mkdir -p %{buildroot}%{_libdir}/ocaml
cp -aLr _build/install/default/lib/* %{buildroot}%{_libdir}/ocaml/

# Makes *.cmxs executable such that they will be stripped.
find %{buildroot} -name '*.cmxs' -exec chmod 0755 {} \;

%files
%license LICENCE
%doc README.md
%dir %{_libdir}/ocaml/mccs/
%{_libdir}/ocaml/mccs/META
%{_libdir}/ocaml/mccs/opam
%{_libdir}/ocaml/mccs/*dune*
%{_libdir}/ocaml/mccs/*.cma
%{_libdir}/ocaml/mccs/*.cmi
%{_libdir}/ocaml/mccs/*.cmx
%{_libdir}/ocaml/mccs/*.cmxs
%{_libdir}/ocaml/stublibs/*.so

%dir %{_libdir}/ocaml/mccs/glpk/
%dir %{_libdir}/ocaml/mccs/glpk/internal/
%{_libdir}/ocaml/mccs/glpk/internal/*.cma
%{_libdir}/ocaml/mccs/glpk/internal/*.cmi
%{_libdir}/ocaml/mccs/glpk/internal/*.cmx
%{_libdir}/ocaml/mccs/glpk/internal/*.cmxs

%files devel
%{_libdir}/ocaml/mccs/*.a
%{_libdir}/ocaml/mccs/*.cmxa
%{_libdir}/ocaml/mccs/*.cmt
%{_libdir}/ocaml/mccs/*.cmti
%{_libdir}/ocaml/mccs/*.ml
%{_libdir}/ocaml/mccs/*.mli

%{_libdir}/ocaml/mccs/glpk/internal/*.a
%{_libdir}/ocaml/mccs/glpk/internal/*.cmxa
%{_libdir}/ocaml/mccs/glpk/internal/*.cmt
%{_libdir}/ocaml/mccs/glpk/internal/*.ml


%changelog
* Sun Jan 10 2021 pterjan <pterjan> 1.1-7.mga8
+ Revision: 1670773
- Rebuild to generate ocamlx provides

* Fri Feb 28 2020 umeabot <umeabot> 1.1-6.mga8
+ Revision: 1551745
- Rebuild for ocaml 4.10.0 final

* Wed Feb 19 2020 umeabot <umeabot> 1.1-5.mga8
+ Revision: 1544528
- Mageia 8 Mass Rebuild

* Sun Jan 26 2020 tv <tv> 1.1-4.mga8
+ Revision: 1483157
- new sub release + rebuild for ocaml-4.10

* Thu Oct 25 2018 daviddavid <daviddavid> 1.1-3.mga7
+ Revision: 1325164
- rebuild for new ocaml 4.07.1

* Sun Sep 23 2018 umeabot <umeabot> 1.1-2.mga7
+ Revision: 1299896
- Mageia 7 Mass Rebuild

* Tue Aug 21 2018 daviddavid <daviddavid> 1.1-1.mga7
+ Revision: 1253295
- initial package ocaml-mccs

